<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use DB;

class Domicile extends Model
{
    /**
     * insert the domicile data
     * @author Faheem Mahar
     * @param $insData
     * @return result
     */
    static function addDomicileData($insData) {
        return DB::table('applicant_info')
        ->insertGetId($insData);
    }
    /**
     * fetch pending domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function fetchPenddingDomiciles() {
        return DB::table('applicant_info')
        ->select('id','name','f_name','cnic')
        ->where('permission','=','pending')
        ->get();
    }
    /**
     * count pending domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function penddingDomicilesCount() {
        return DB::table('applicant_info')
        ->select('id')
        ->where('permission','=','pending')
        ->count();
    }
    /**
     * count cancelled domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function cancelledDomicilesCount() {
        return DB::table('applicant_info')
        ->select('id')
        ->where('officer_issued_on_date','=',date('d/m/Y', time()))
        ->where('permission','=','CANCELLED')
        ->count();
    }
    /**
     * count cancelled domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function cancelledAllDomicilesCount() {
        return DB::table('applicant_info')
        ->select('id')
        //->where('officer_issued_on_date','=',date('d/m/Y', time()))
        ->where('permission','=','CANCELLED')
        ->count();
    }
    /**
     * count issued domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function issuedDomicilesCountToday() {
        return DB::table('applicant_info')
        ->select('id')
        ->where('officer_issued_on_date','=',date('d/m/Y', time()))
        ->where('permission','=','Issued')
        ->count();
    }
    /**
     * fetch all cases
     * @author Faheem Mahar
     * @return result
     */
    static function fetchAllCases($date) {

        return DB::table('applicant_info')
        
        ->select('applicant_info.name','applicant_info.f_name','applicant_info.cnic','branch_id as branch',
        'image_path','docs_path','permission','ts','profile_created_date')
        
        //->whereDate('ts','=',$date)
        ->where("profile_created_date","=",$date)
        ->get();

    }
    /**
     * fetch issue domiciles by filter
     * @author Faheem Mahar
     * @return result
     */
    static function issuedDomicilesFilter($filter) {
        return DB::table('applicant_info')
        ->select('applicant_info.name','applicant_info.f_name','applicant_info.cnic',
        'applicant_info.challan_no','applicant_info.challan_date',
        'domicileissued.domicile_number','formc_issued.formc_number','formd_issued.formd_number')
        ->leftJoin('domicileissued',function($join) {
            $join->on('domicileissued.ref_id','=','applicant_info.id');
            //->where('domicileissued.cnic','=','applicant_info.cnic');
        })
        
        ->leftJoin('formc_issued',function($join) {
            $join->on('formc_issued.ref_id','=','applicant_info.id');
           // ->where('formc_issued.cnic','=','applicant_info.cnic');
        })
        
        ->leftJoin('formd_issued',function($join) {
            $join->on('formd_issued.ref_id','=','applicant_info.id');
            //->where('formd_issued.cnic','=','applicant_info.cnic');
        })
        ->where('officer_issued_on_date','=',$filter)
        ->where('permission','=','Issued')
        ->get();
    }
    /**
     * count issued domiciles
     * @author Faheem Mahar
     * @return result
     */
    static function issuedDomicilesCount() {
        return DB::table('applicant_info')
        ->select('id')
        ->where('officer_issued_on_date','=',date('d/m/Y', time()))
        ->where('permission','=','ISSUED')
        ->count();
    }
    /**
     * check applicant already exist
     * @author Faheem Mahar
     * @param $cnic
     * @return result {int} 
     */
    static function applicantExist($cnic) {
        return DB::table('applicant_info')
        ->select('id')
        ->where('cnic','=',$cnic)
        ->count();
    }
    
    /**
     * check applicant already exist
     * @author Faheem Mahar
     * @param $cnic
     * @return result {obj} 
     */
    static function fetchApplicant($cnic) {
        return DB::table('applicant_info')
        ->select('id','name','f_name','address_present','address_parmanent','officer_issued_on_date','permission','officer_comments','note','branch_id')
        ->where('cnic','=',$cnic)
        ->first();
    }
    /**
     * fetch applicant details
     * @author Faheem Mahar
     * @param $cnic
     * @return result {obj} 
     */
    static function fetchApplicantDetails($cnic) {
        return DB::table('applicant_info')
        ->select('id','name','f_name','address_present','address_parmanent',
        'image_path','docs_path','contact_no','permission','cnic','profile_created_date')
        ->where('cnic','=',$cnic)
        ->first();
    }
    /**
     * fetch applicant details
     * @author Faheem Mahar
     * @return result {obj} 
     */
    static function fetchCasesExceptIssued() {
        return DB::table('applicant_info')
        ->select('id','name','f_name','address_present','address_parmanent','image_path','docs_path','contact_no','permission','cnic')
        ->where('permission','!=','ISSUED')
        ->where('permission','!=','pending')
        ->get();
    }
    /**
     * fetch applicant details
     * @author Faheem Mahar
     * @return result {obj} 
     */
    static function fetchExceptIssuedCases($startDate,$endDate) {
        return DB::table('applicant_info')
        ->select('id','name','f_name','address_present','address_parmanent',
        'image_path','docs_path','contact_no','permission','cnic','ts')
        ->where('permission','!=','ISSUED')
        ->whereDate('ts','=',$startDate)
        //->whereBetween('ts',[$startDate,$endDate])
        ->get();
    }
    /**
     * fetch issued cases between given dates
     * @author Faheem Mahar
     * @param $startDate
     * @param $endDate
     * @return result {obj} 
     */
    static function fetchIssuedCasesBetweenDates($startDate,$endDate) {
        return DB::table('applicant_info')
        ->select('applicant_info.id','applicant_info.name','applicant_info.f_name','applicant_info.address_present',
        'applicant_info.address_parmanent','applicant_info.image_path','applicant_info.docs_path','applicant_info.contact_no',
        'applicant_info.permission','applicant_info.cnic',DB::raw("CONCAT(applicant_info.officer_issued_on_date,' ',applicant_info.officer_issued_on_time) AS issued_date_time"),
        'domicileissued.domicile_number','formc_issued.formc_number','formd_issued.formd_number','cnic_issued_date',
        'guardian_cnic_no'
        )
        ->leftJoin('domicileissued','applicant_info.id','=','domicileissued.ref_id')
        ->leftJoin('formc_issued','applicant_info.id','=','formc_issued.ref_id')
        ->leftJoin('formd_issued','applicant_info.id','=','formd_issued.ref_id')
        ->where('applicant_info.permission','=','ISSUED')
        ->where('applicant_info.officer_issued_on_date', '=', $startDate)
        //->where('applicant_info.officer_issued_on_date', '<=', $endDate)
        //->whereBetween('applicant_info.officer_issued_on_date',[$startDate,$endDate])
        
        //->whereMonth('applicant_info.ts','=',"06")
        
        //->whereMonth('applicant_info.ts','=',"06")

        ->orderBy('applicant_info.name','ASC')

        ->get();
    }
    /**
     * fetch applicant verified docs
     * @author Faheem Mahar
     * @param $id
     * @return result {obj} 
     */
    static function fetchVerifiedDoc($id) {
        return DB::table('verified_docs')
        ->select('doc_path')
        ->where('applicant_id','=',$id)
        ->first();
    }
    /**
     * fetch applicant verified docs
     * @author Faheem Mahar
     * @param $id
     * @return result {obj} 
     */
    static function fetchAllVerifiedDoc($id) {
        return DB::table('verified_docs')
        ->select('applicant_id','doc_path')
        ->whereIn('applicant_id',$id)
        ->get();
    }
    /**
     * update domicile status
     * @author Faheem Mahar
     * @param $cnic
     * @param $comment
     * @param $status
     * @return result {int} 
     */
    static function updateDomicileStatus($cnic,$status,$comment,$time) {
        return DB::table('applicant_info')
        ->where('cnic','=',$cnic)
        ->update(['permission' => $status,'officer_comments' => $comment,'officer_issued_on_date' => date('d/m/Y', time()),'officer_issued_on_time' => $time]);
    }
    /**
     * update domicile
     * @author Faheem Mahar
     * @param $domicileId
     * @param  $col
     * @param $val
     */
    static function updateDomicile($domicileId,$col,$val) {
        return DB::table('applicant_info')
        ->where('id', '=', $domicileId)
        ->update([$col => $val]);
    }
    /**
     * update domicile status
     * @author Faheem Mahar
     * @param $keyword 
     */
    static function searchApplicant($keyword) {
        
        return DB::table('applicant_info')
        
        // ->select(['applicant_info.*','domicileissued.domicile_number','formc_issued.formc_number','formd_issued.formd_number',
        // 'applicant_info.cnic','domicileissued.cnic','formc_issued.cnic','formd_issued.cnic','applicant_info.id as myid'])
        
        // ->leftJoin('domicileissued',function($join) {
        //     $join->on('domicileissued.ref_id','=','applicant_info.id');
        //     //->where('domicileissued.cnic','=','applicant_info.cnic');
        // })
        
        // ->leftJoin('formc_issued',function($join) {
        //     $join->on('formc_issued.ref_id','=','applicant_info.id');
        //    // ->where('formc_issued.cnic','=','applicant_info.cnic');
        // })
        
        // ->leftJoin('formd_issued',function($join) {
        //     $join->on('formd_issued.ref_id','=','applicant_info.id');
        //     //->where('formd_issued.cnic','=','applicant_info.cnic');
        // })
        
        //->where('applicant_info.name', '=', strtoupper($keyword))
        ->where('applicant_info.name','like','%'.strtoupper($keyword).'%')
        //'name', 'like', '%' . Input::get('name') . '%'
        ->orWhere('applicant_info.cnic', '=', $keyword)
        
        ->orWhere('applicant_info.contact_no','=',$keyword)
        
        ->orWhere('applicant_info.id', '=',$keyword)
        
        //->groupBy(['formc_issued.cnic'])
        
        ->get();
    }
    /**
     * get domicile related data
     * @author Faheem Mahar
     * @return $result {array}
     */
    static function fetchDomicileOtherData($applicantId) {
        
        $domicileNumber = DB::table('domicileissued')
        ->select('domicile_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->orderBy('domicile_number','desc')
        ->first();

        $formCNumber = DB::table('formc_issued')
        ->select('formc_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->first();

        $formDNumber = DB::table('formd_issued')
        ->select('formd_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->first();
        
        $formDNumber_       = 0;
        $formCNumber_       = 0;
        $domicileNumber_    = 0;

        $formDIssuedDate = '';
        $formCIssuedDate = '';
        $domicileIssuedDate = '';
        if(is_object($formDNumber) && $formDNumber->formd_number !=null) {
            $formDNumber_ = $formDNumber->formd_number;
            $formDIssuedDate = $formDNumber->date_issued;
        }
        if(is_object($formCNumber) && $formCNumber->formc_number !=null) {
            $formCNumber_ = $formCNumber->formc_number;
            $formCIssuedDate = $formCNumber->date_issued;
        }
        if(is_object($domicileNumber) && $domicileNumber->domicile_number !=null) {
            $domicileNumber_ = $domicileNumber->domicile_number;
            $domicileIssuedDate = $domicileNumber->date_issued;
        }

        return ['domicileNumber'    => $domicileNumber_
            , 'formCNumber'         => $formCNumber_
            , 'formDNumber'         => $formDNumber_
            ,'formDIssuedDate'      => $formDIssuedDate
            , 'formCIssuedDate'     => $formCIssuedDate
            ,'domicileIssuedDate'   => $domicileIssuedDate
        ];
    }
    /**
     * get domicile related data
     * @author Faheem Mahar
     * @return $result {array}
     */
    static function fetchDomicileAllOtherData($applicantId) {
        
        $domicileNumber = DB::table('domicileissued')
        ->select('ref_id','domicile_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->orderBy('domicile_number','desc')
        ->get();

        $formCNumber = DB::table('formc_issued')
        ->select('ref_id','formc_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->get();

        $formDNumber = DB::table('formd_issued')
        ->select('ref_id','formd_number','date_issued')
        ->whereIn('ref_id',$applicantId)
        ->get();
        
        

        return ['domicile'    => $domicileNumber
            , 'formC'         => $formCNumber
            , 'formD'         => $formDNumber
        ];
    }
    /**
     * get last insert domicile id
     * @author Faheem Mahar
     * @return $id {int}
     */
    static function getLastInsertedId() {
        return DB::table('applicant_info')
        ->select('year_id')
        ->orderBy('id','desc')
        ->first();
    }
    /**
     * get last insert form d id
     * @author Faheem Mahar
     * @return $id {int}
     */
    static function getLastInsertedFormDId() {
        return DB::table('formd_issued')
        ->select('id')
        ->orderBy('id','desc')
        ->first();
    }
    /**
     * get last insert form c id
     * @author Faheem Mahar
     * @return $id {int}
     */
    static function getLastInsertedFormCId() {
        return DB::table('formc_issued')
        ->select('id')
        ->orderBy('id','desc')
        ->first();
    }
    /**
     * get inserted record year
     * @author Faheem Mahar
     * @return $year
     */
    static function getYear($id) {
        return DB::table('applicant_info')
        ->select('ts')
        ->where('id','=',$id)
        ->first();
    }
     /**
     * get inserted record year
     * @author Faheem Mahar
     * @return $year
     */
    static function getYearId() {
        return DB::table('applicant_info')
        ->select('year_id')
        ->orderBy('year_id','DESC')
        ->first();
    }
    /**
     * get time stamp last added record
     * @author Faheem Mahar
     * @return $ts
     */
    static function fetchTS() {
        return DB::table('applicant_info')
        ->select('ts')
        ->orderBy('id','DESC')
        ->first();
    }
    /**
     * update year id
     * @author Faheem Mahar
     * @param $id
     * @param $yearId
     * @return int
     */
    static function updateYearId($id,$yearId) {
        return DB::table('applicant_info')
        ->where('id','=',$id)
        ->update(['year_id' => $yearId]);
    }
    /**
     * issue new domicile
     * @author Faheem Mahar
     * @param $insData
     * @return $result 
     */
    static function issueDomicile($insData) {
        $hasRec =DB::table('domicileissued')->where('ref_id','=',$insData['ref_id'])->count(); 
        if($hasRec == 0)
            return DB::table('domicileissued')->insertGetId($insData);
        else
            return DB::table('domicileissued')->where('ref_id','=',$insData['ref_id'])->update($insData);   
    }
    /**
     * issue new domicile
     * @author Faheem Mahar
     * @return $result 
     */
    static function getLastIssuedDomicileId() {
        return DB::table('domicileissued')
        ->select('id')
        ->orderBy('id','desc')
        ->first();   
    }
    /**
     * issue new form d 
     * @author Faheem Mahar
     * @param $insData
     * @return $result 
     */
    static function issueFormD($insData) {
        $hasRec = DB::table('formd_issued')->where('ref_id','=',$insData['ref_id'])->count();
        if($hasRec == 0)
            return DB::table('formd_issued')->insertGetId($insData);
        else
            return DB::table('formd_issued')->where('ref_id','=',$insData['ref_id'])->update($insData);
    }
    /**
     * issue new form c
     * @author Faheem Mahar
     * @param $insData
     * @return $result 
     */
    static function issueFormC($insData) {
        $hasRec = DB::table('formc_issued')->where('ref_id','=',$insData['ref_id'])->count();
        if($hasRec == 0)
            return DB::table('formc_issued')->insertGetId($insData);
        else
            return DB::table('formc_issued')->where('ref_id','=',$insData['ref_id'])->update($insData);   
    }
    /**
     * update the file 
     * @author Faheem Mahar
     * @param $recordId
     * @param $file
     * @return $result 
     */
    static function updateFile($recordId,$file) {
        
        return DB::table('applicant_info')
        
        ->where('id','=',$recordId)

        ->update(['docs_path' => $file]);
    }
    /**
     * fetch user's single column data
     * @author Faheem Mahar
     * @param $recordId
     * @return result
     */
    static function fetchColData($recordId,$col) {
        
        return DB::table('applicant_info')
        
        ->select($col)
        
        ->where('id','=',$recordId)

        ->first();
    }
    /**
     * update the record
     * @author Faheem Mahar
     * @param $recordId
     * @param $file
     * @return $result 
     */ 
    static function updateColVal($recordId,$col,$val) {
        
        return DB::table('applicant_info')
        
        ->where('id','=',$recordId)

        ->update([$col => $val]);
    }
    /**
     * update the applicant profile info
     * @author Faheem Mahar
     * @param $updateData
     * @param $recordId
     * @return $result 
     */
    static function updateApplicantProfile($updateData,$recordId) {
        
        return DB::table('applicant_info')
        
        ->where('id','=',$recordId)

        ->update($updateData);
    }
    /**
     * update the verified docs
     * @author Faheem Mahar
     * @param $docLink
     * @param $recordId
     * @return result 
     */
    static function updateVerifiedDoc($recordId,$docLink) {
        
        $hasRec = DB::table('verified_docs')
        
        ->where('applicant_id','=',$recordId)
        
        ->count();

        if($hasRec) {
            return DB::table('verified_docs')
        
            ->where('applicant_id','=',$recordId)
            
            ->update(['doc_path' => $docLink]);
        }
        else {
            return DB::table('verified_docs')
        
            ->insert(['applicant_id' => $recordId, 'doc_path' => $docLink]);   
        }

    }
    /**
     * filter the issued cases 
     * @author Faheem Mahar
     * @param $month
     * @param $year
     * @return result 
     */
    static function filterIssueDomicile($month,$year) {
        // return [$month,$year];
        if($month !="" && $year !="") {
           
            return DB::table('domicileissued')
            ->select(['domicileissued.ref_id','domicileissued.name','domicileissued.f_name',
            'domicileissued.cnic','domicileissued.address_present','domicileissued.address_parmanent',
            'domicileissued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','domicileissued.ref_id')

            ->whereYear('domicileissued.ts','=',$year)
            
            ->whereMonth('domicileissued.ts','=',$month)

            ->get();
        }
        else {
            //return ['where' => 'in else'];
            return DB::table('domicileissued')
            ->select(['domicileissued.ref_id','domicileissued.name','domicileissued.f_name',
            'domicileissued.cnic','domicileissued.address_present','domicileissued.address_parmanent',
            'domicileissued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','domicileissued.ref_id')
            ->get();
        }
    }
    /**
     * filter except the issued cases 
     * @author Faheem Mahar
     * @param $month
     * @param $year
     * @return result 
     */
    static function filterExceptIssueDomicile($month,$year) {
        
            
        return DB::table('applicant_info')
        ->select(['applicant_info.name','applicant_info.f_name',
        'applicant_info.cnic','applicant_info.address_present','applicant_info.address_parmanent',
        'applicant_info.ts',"permission"])
        
        ->whereYear('applicant_info.ts','=',$year)
        
        ->whereMonth('applicant_info.ts','=',$month)
        
        ->where('permission',"!=","ISSUED")
        
        ->get();
       
    }
    /**
     * filter the issued cases 
     * @author Faheem Mahar
     * @param $month
     * @param $year
     * @return result 
     */
    static function filterIssueFormC($month,$year) {
        if($month !="" && $year !="") {
            return DB::table('formc_issued')
            ->select(['formc_issued.ref_id','formc_issued.name','formc_issued.f_name',
            'formc_issued.cnic','formc_issued.address_present','formc_issued.address_parmanent',
            'formc_issued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','formc_issued.ref_id')
            ->whereYear('formc_issued.ts','=',$year)
            ->whereMonth('formc_issued.ts','=',$month)
            ->get();
        }
        else {
            return DB::table('formc_issued')
            ->select(['formc_issued.ref_id','formc_issued.name','formc_issued.f_name',
            'formc_issued.cnic','formc_issued.address_present','formc_issued.address_parmanent',
            'formc_issued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','formc_issued.ref_id')
            ->get();
        }
    }
    /**
     * filter the issued cases 
     * @author Faheem Mahar
     * @param $month
     * @param $year
     * @return result 
     */
    static function filterIssueFormD($month,$year) {
        if($month !="" && $year !="") {
            return DB::table('formd_issued')
            ->select(['formd_issued.ref_id','formd_issued.name','formd_issued.f_name',
            'formd_issued.cnic','formd_issued.address_present','formd_issued.address_parmanent',
            'formd_issued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','formd_issued.ref_id')
            ->whereYear('formd_issued.ts','=',$year)
            ->whereMonth('formd_issued.ts','=',$month)
            ->get();
        }
        else {
            return DB::table('formd_issued')
            ->select(['formd_issued.ref_id','formd_issued.name','formd_issued.f_name',
            'formd_issued.cnic','formd_issued.address_present','formd_issued.address_parmanent',
            'formd_issued.ts','applicant_info.branch_id as type'])
            ->leftJoin('applicant_info','applicant_info.id','=','formd_issued.ref_id')
            ->get();
        }
    }
}
