<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Users;
use App\Models\User;
use Crypt;
use Carbon\Carbon;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage;
use LynX39\LaraPdfMerger\Facades\PdfMerger;

class domicileApi extends Controller
{
    public function __construct() {
        date_default_timezone_set("Asia/Karachi");
    }
    /**
     * utility  function for fileName from given url
     * 
     * @param $url
     * @return $fileName{string}
     */
    private function getFileName($url) {
        
        $parts = parse_url($url);

        $path = $parts['path'];

        $pathArr = explode('/',$path);
        
        return $pathArr[4];
    }
    /**
     * upload user's remaining documents
     * 
     * @param  \Illuminate\Http\Request  $request
	 * @return \Illuminate\Http\Response
     */
    function uploadRemainingDocs(Request $request) {
        try {
            $request->validate([
                'record_id' => 'required',
                'new_docpath' => 'required'
            ]);
            
            $recordId = $request->record_id;

            $uploadedDocs = Domicile::fetchColData($recordId,'docs_path');
            
            
            $pathOne = $uploadedDocs->docs_path;
            
            $pathTwo = $request->new_docpath;
            
            $file1 = $this->getFileName($pathOne);

            $file2 = $this->getFileName($pathTwo);

            $rootPath  = public_path('documents/'.$file1);

            $rootPath2 = public_path('documents/'.$file2);

            $fileName = time().'_merge_document.pdf';

            $oMerger = PDFMerger::init();

            $oMerger->addPDF($rootPath,'all');// one fie
            
            $oMerger->addPDF($rootPath2, 'all');//2nd file

            $oMerger->merge();//merge file

            $oMerger->save(public_path('documents/'.$fileName));//save the new file
            
            $uri = url('public/documents/').'/'.$fileName;

            Domicile::updateColVal($recordId,'docs_path',$uri);//update new file
            
            unlink($rootPath);//remove file

            unlink($rootPath2);//remove file

            return response([
                "status" => "success",
                "message" => "File successfully uploaded",
                "file" => $fileName,
                "file_path" => $uri
            ]);

            
        }
        catch(\Exception $e) {
			return response(['status' => 'error', 'message' => $e->getMessage()]);
		}
        //var_dump($oMerger);
    }
	/**
	 * upload the image 
	 *
	 * @param  \Illuminate\Http\Request  $request
	 * @return \Illuminate\Http\Response
	*/
	public function uploadImage(Request $request) {
		
		try {
			
			$request->validate([
                'image' => 'required',
            ]);

			// $imageData = $request->input('image');
			
			// $imageData = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '',$imageData));
			
			// $imageName = 'domicile_profile_'.time().'_image_'.rand('100000','1000000000').'.jpeg';

			
        	// $success = file_put_contents(public_path().'/uploads/'.$imageName, $imageData);
            
            $imageName = 'domicile_profile_'.time().'_image.'.$request->image->extension();  
     
            $success = $request->image->move(public_path('uploads'), $imageName);

	        //$image->move($destinationPath, $name);
			//Storage::disk('public/images')->put($imageName, $imageData);
			
			return response([
	                "status" => "success",
	                "message" => $success,
	                "image" => $imageName,
	                'image_path' => url('public/uploads/').'/'.$imageName
	        ]);
		}
		catch(\Exception $e) {
			return response(['status' => 'error', 'message' => $e->getMessage()]);
		}
    }
    /**
	 * upload verified pdf 
	 *
	 * @param  \Illuminate\Http\Request  $request
	 * @return \Illuminate\Http\Response
    */
    public function uploadVerifiedPdf(Request $request) {
        try {
            
            $validator = Validator::make($request->all(), 
              [ 
              'file' => 'required|mimes:pdf',
             ]);   
 
	    	if ($validator->fails()) {          
	            return response(['error'=>$validator->errors()], 401);                        
	        }
	        if ($file = $request->file('file')) {
	             
	            $fileName = time().'_verified_document.'.$request->file->extension();  
   
                $file = $request->file->move(public_path('verified_documents'), $fileName);

                
                return response([
                    "status" => "success",
                    "message" => "File successfully uploaded",
                    "file" => $fileName,
                    "file_path" => url('public/verified_documents/').'/'.$fileName
                ]);
                
	        }	
		} catch (\Exception $e) {
			return response(['status' => 'error', 'message' => $e->getMessage()]);
		}
    }
    /**
     * update verified document path
     * 
     *  @param  \Illuminate\Http\Request  $request
     *  @return \Illuminate\Http\Response
     */
    public function updateVerifiedDoc(Request $request) {
        try {
            
            $request->validate([
                'record_id' => 'required',
                'doc_path'  => 'required'
            ]);
            
            $updateStatus = Domicile::updateVerifiedDoc($request->record_id,$request->doc_path);

            return response(['status' => 'success', 'data' => $updateStatus]);
        }
        catch (\Exception $e) {
			return response(['status' => 'error', 'message' => $e->getMessage()]);
		}

    }
	/**
	 * upload the pdf 
	 *
	 * @param  \Illuminate\Http\Request  $request
	 * @return \Illuminate\Http\Response
	*/
	public function uploadPdf(Request $request) {
		
		try {
            
            $validator = Validator::make($request->all(), 
              [ 
              'file' => 'required|mimes:pdf',
             ]);   
 
	    	if ($validator->fails()) {          
	            return response(['error'=>$validator->errors()], 401);                        
	        }
	        if ($file = $request->file('file')) {
	             
	            $fileName = time().'_document.'.$request->file->extension();  
   
                $file = $request->file->move(public_path('documents'), $fileName);

                if($request->has('record_id')) {
                    Domicile::updateFile($request->get('record_id'),url('public/documents/').'/'.$fileName);
                    return response([
                        "status" => "success",
                        "message" => "File successfully uploaded and updated",
                        "file" => $fileName,
                        "file_path" => url('public/documents/').'/'.$fileName
                    ]);
                }
                else {
                    return response([
                        "status" => "success",
                        "message" => "File successfully uploaded",
                        "file" => $fileName,
                        "file_path" => url('public/documents/').'/'.$fileName
                    ]);
                }
	        }	
		} catch (\Exception $e) {
			return response(['status' => 'error', 'message' => $e->getMessage()]);
		}  	
	}
    /**
     * login the user.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function login(Request $request)
    {
        try {
            $request->validate([
                'user_name' => 'required',
                'user_password' => 'required'
            ]);
            
            $userName       = $request->user_name;
            
            $userPassword   = $request->user_password;
            
            $loginData = Users::login($userName,$userPassword);
            if(is_object($loginData) && Crypt::decrypt($loginData->user_password) == $request->user_password) {
                $loginDataArr = json_decode(json_encode($loginData),true);
                $loginDataArr['is_login'] = 1;
                return response(['status' => 'success', 'data' => $loginDataArr]);
            }
            else {
                $loginDataArr['is_login'] = 0;
                return response(['status' => 'success', 'data' => $loginDataArr]);
            }
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * store domicile data in storage
     * 
     *  @param  \Illuminate\Http\Request  $request
     *  @return \Illuminate\Http\Response
     */
    public function addDomicileData(Request $request) {
        try {

            $domicileData = $request->all();
            
            $cnic = $domicileData['cnic'];

            if(Domicile::applicantExist($cnic) == 0) {
                
                $beforeInsYear = Domicile::fetchTS();
                
                $getYearId = Domicile::getYearId();

                $yearId = 1;
                
                if(is_object($getYearId))
                    $yearId = $getYearId->year_id + 1;
                

                if(is_object($beforeInsYear))
                	$beforeInsYear = Carbon::parse($beforeInsYear->ts)->year;
                else
                	$beforeInsYear = date('Y');

                $insId = Domicile::addDomicileData($domicileData);
                
                $year = Domicile::getYear($insId);
                
                $year = Carbon::parse($year->ts)->year;
                if($year < $beforeInsYear ) {
                    Domicile::updateYearId($insId,$yearId);// if year change then start id from 1 
                }
                elseif($year == $beforeInsYear ) {//if the year is same
                    Domicile::updateYearId($insId,$yearId);
                }
                
                return response(['status' => 'success', 'insId' => $insId]);
            }
            else {
                return response(['status' => 'error', 'message' => 'Applicant already exist.']);
            }
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }

    }
    /**
     * fetch applicant specific details.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchApplicantDetails(Request $request)
    {
        try {
            $request->validate([
                'cnic' => 'required',
            ]);
            $applicant = Domicile::fetchApplicantDetails($request->cnic);
            $domicileOtherData  = [];
            if(is_object($applicant)) {
                $applicantsArr = json_decode(json_encode($applicant),true);
                $id = array_column($applicantsArr, 'id');
                $domicileOtherData = Domicile::fetchDomicileOtherData($id);
            }
            return response(['status' => 'success', 'data' => $applicant,'domicileOtherData' => $domicileOtherData]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }

    /**
     * Display the specified domicile details.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function showDomicilesDetails(Request $request)
    {
        try {

            $pendingDomiciles        = Domicile::fetchPenddingDomiciles();
            
            $pendingDomicilesCount   = Domicile::penddingDomicilesCount();
            
            $cancelledDomicilesCount = Domicile::cancelledDomicilesCount();

            $issuedDomicilesCount    = Domicile::issuedDomicilesCount();

            $data = ['pendingDomiciles' => $pendingDomiciles, 'pendingDomicilesCount' => $pendingDomicilesCount,'cancelledDomicilesCount' => $cancelledDomicilesCount, 'issuedDomicilesCount' => $issuedDomicilesCount];
            return response(['status' => 'success', 'data' => $data]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * Update the specified domicile status.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function updateColVal(Request $request) {
        try {
            $recordId = $request->record_id;
            $col = $request->col;
            $val = $request->val;
            $update = Domicile::updateColVal($recordId,$col,$val);
            return response(['status' => 'success', 'data' => $update]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * Update the specified domicile status.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function updateDomicile(Request $request) {
        try {
            $domicileId = $request->domicile_id;
            $col = $request->col;
            $val = $request->val;
            $update = Domicile::updateDomicile($domicileId,$col,$val);
            return response(['status' => 'success', 'data' => $update]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
     /**
     * issue user's remianing docs like form c & d.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    function issueRemainingDocs(Request $request) {
        try {
            $request->validate([
                'cnic'      => 'required',
                'which_doc' => 'required'
            ]);
            $applicantData  = Domicile::fetchApplicant($request->cnic);
            $request->merge([
                'ref_id'            => $applicantData->id,
                'name'              => $applicantData->name,
                'f_name'            => $applicantData->f_name,
                'address_present'   => $applicantData->address_present,
                'address_parmanent' => $applicantData->address_parmanent,
                'cnic'              => $request->cnic,
                'date_issued'       => date('d/m/Y', time()),
                'is_issued'         =>  1,
                'system_id'         => '',
                'note'              => $applicantData->note,
                'branch_id'         => $applicantData->branch_id
            ]);
            if($request->which_doc == 'form_c') {
                $this->generateFormCId($request);//generate formc
            }
            if($request->which_doc == 'form_d') {
                $this->generateFormDId($request);//generate formd
            }
            if($request->which_doc == 'domicile') {
                $this->generateDomicileId($request);//generate domicile
            }
            return response(['status' => 'success', 'update' => 1]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * Update the specified domicile status.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function updateDomicileStatus(Request $request)
    {
        try {
            $now         = Carbon::now();
            $time        = $now->format('g:i A');
            $comment     = $request->comment;
            $status      = $request->status;
            $cnic        = $request->cnic;
            $hasDomicile = $request->has_domicile;
            $hasFormc    = $request->has_formc;
            $hasFormd    = $request->has_formd;
            
            $isUpdate       = Domicile::updateDomicileStatus($cnic,$status,$comment,$time);
            $applicantData  = Domicile::fetchApplicant($cnic);
            $request->merge([
                'ref_id'            => $applicantData->id,
                'name'              => $applicantData->name,
                'f_name'            => $applicantData->f_name,
                'address_present'   => $applicantData->address_present,
                'address_parmanent' => $applicantData->address_parmanent,
                'cnic'              => $cnic,
                'date_issued'       => $applicantData->officer_issued_on_date,
                'is_issued'         =>  1,
                'system_id'         => '',
                'note'              => $applicantData->note,
                'branch_id'         => $applicantData->branch_id
            ]);
            if($hasDomicile == 1 && $hasFormc == 0 && $hasFormd == 0) {
                $this->generateDomicileId($request);//gerate domicile
            }
            elseif($hasDomicile == 1 && $hasFormc == 1 && $hasFormd == 0) {
                $this->generateDomicileId($request);//gerate domicile
                $this->generateFormCId($request);//generate formc
            }
            elseif($hasDomicile == 1 && $hasFormc == 0 && $hasFormd == 1) {
                $this->generateDomicileId($request);//gerate domicile
                $this->generateFormDId($request);//generate formd
            }
            elseif($hasDomicile == 1 && $hasFormc == 1 && $hasFormd == 1) {
                $this->generateDomicileId($request);//gerate domicile
                $this->generateFormCId($request);//generate formc
                $this->generateFormDId($request);//generate formd
            }
            elseif($hasDomicile == 0 && $hasFormc == 0 && $hasFormd == 1) {
                //$this->generateDomicileId($request);//gerate domicile
                //$this->generateFormCId($request);//generate formc
                $this->generateFormDId($request);//generate formd
            }
            elseif($hasDomicile == 0 && $hasFormc == 1 && $hasFormd == 0) {
                //$this->generateDomicileId($request);//gerate domicile
                $this->generateFormCId($request);//generate formc
                //$this->generateFormDId($request);//generate formd
            }
            return response(['status' => 'success', 'update' => $isUpdate]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch issued cases between dates.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchIssuedCasesBetweenDates(Request $request) {
        try {
            $request->validate([
                'start_date' => 'required',
                'end_date' => 'required'
            ]);
            
            $data = Domicile::fetchIssuedCasesBetweenDates($request->start_date,$request->end_date);
            
            // $dataArr = json_decode(json_encode($data),true);

            // $ids = array_column($dataArr, 'id');
            // $domicileOtherData = Domicile::fetchDomicileAllOtherData($ids);
            // $verifiedDocData = Domicile::fetchAllVerifiedDoc($ids);
            // if(count($verifiedDocData) == 0)
            //     $verifiedDocData = ['doc_path' => 'no verified attachment found.'];
            
            // return response(['status' => 'success', 'data' => $data,'domicileOtherData' => $domicileOtherData,
            // 'verifiedDocData' => $verifiedDocData
            // ]);
            return response(['status' => 'success', 'data' => $data]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch cases except approved.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchCasesExceptIssued(Request $request) {
        try {
            $data = Domicile::fetchCasesExceptIssued();
            return response(['status' => 'success', 'data' => $data]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch cases except approved.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchExceptIssuedCases(Request $request) {
        try {
            $request->validate([
                'start_date' => 'required',
                'end_date'   => 'required'
            ]);
            $data = Domicile::fetchExceptIssuedCases($request->start_date,$request->end_date);
            
            return response(['status' => 'success', 'data' => $data]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * search applicant.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function searchApplicant(Request $request)
    {
        try {
            $request->validate([
                'keyword' => 'required'
            ]);
            $keyword    = $request->keyword;
            $applicants = Domicile::searchApplicant($keyword);
            if(count($applicants) > 0) {
                $applicantsArr = json_decode(json_encode($applicants),true);
                $id = array_column($applicantsArr, 'id');
                $domicileOtherData = Domicile::fetchDomicileOtherData($id);
                $verifiedDocData = Domicile::fetchVerifiedDoc($id);
                if(!is_object($verifiedDocData))
                    $verifiedDocData = ['doc_path' => 'no verified attachment found.'];
                //$applicants['is_data'] = 1;
                return response(['status' => 'success', 'data' => $applicants,'is_data' => 1,
                'domicileOtherData' => $domicileOtherData,'verifiedDocData' => $verifiedDocData]);
            }
            else {
                return response(['status' => 'success', 'data' => [],'is_data' => 0]);
            }
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * generate the domicile number
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function generateDomicileId(Request $request) {
        try {
            $id = Domicile::getLastIssuedDomicileId();
            $domicileId         = isset($id->id) ? $id->id + 1 : 1;
            $refId              = $request->ref_id;
            $name               = $request->name;
            $fName              = $request->f_name;
            $addressPresent     = $request->address_present;
            $addressPermanent   = $request->address_parmanent;
            $cnic               = $request->cnic;
            $dateIssued         = $request->date_issued;
            $isIssued           = $request->is_issued;
            $systemId           = $request->system_id;
            $note               = $request->note;
            $branchId           = $request->branch_id;

            $insData = [];
            $insData['ref_id']              = $refId;
            $insData['domicile_number']     = $domicileId;
            $insData['name']                = $name;
            $insData['f_name']              = $fName;
            $insData['address_present']     = $addressPresent;
            $insData['address_parmanent']   = $addressPermanent;
            $insData['cnic']                = $cnic;
            $insData['date_issued']         = $dateIssued;
            $insData['is_issued']           = $isIssued;
            $insData['system_id']           = $systemId;
            $insData['note']                = $note;
            $insData['branch_id']           = $branchId;
           
            $issueDomicile = Domicile::issueDomicile($insData);

            return response(['status' => 'success', 'data' => $issueDomicile]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * generate the form d number
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function generateFormDId(Request $request) {
        try {
            $id = Domicile::getLastInsertedFormDId();
            $formDId            = isset($id->id) ? $id->id + 1 : 1;
            $refId              = $request->ref_id;
            $name               = $request->name;
            $fName              = $request->f_name;
            $addressPresent     = $request->address_present;
            $addressPermanent   = $request->address_parmanent;
            $cnic               = $request->cnic;
            $dateIssued         = $request->date_issued;
            $isIssued           = $request->is_issued;
            $systemId           = $request->system_id;
            $note               = $request->note;
            $branchId           = $request->branch_id;

            $insData = [];
            $insData['ref_id']              = $refId;
            $insData['formd_number']        = $formDId;
            $insData['name']                = $name;
            $insData['f_name']              = $fName;
            $insData['address_present']     = $addressPresent;
            $insData['address_parmanent']   = $addressPermanent;
            $insData['cnic']                = $cnic;
            $insData['date_issued']         = $dateIssued;
            $insData['is_issued']           = $isIssued;
            $insData['system_id']           = $systemId;
            $insData['note']                = $note;
            $insData['branch_id']           = $branchId;
           
            $issueFormD = Domicile::issueFormD($insData);

            return response(['status' => 'success', 'data' => $issueFormD]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * generate the form c number
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function generateFormCId(Request $request) {
        try {
            $id = Domicile::getLastInsertedFormCId();
            $formCId            = isset($id->id) ? $id->id + 1 : 1;
            $refId              = $request->ref_id;
            $name               = $request->name;
            $fName              = $request->f_name;
            $addressPresent     = $request->address_present;
            $addressPermanent   = $request->address_parmanent;
            $cnic               = $request->cnic;
            $dateIssued         = $request->date_issued;
            $isIssued           = $request->is_issued;
            $systemId           = $request->system_id;
            $note               = $request->note;
            $branchId           = $request->branch_id;

            $insData = [];
            $insData['ref_id']              = $refId;
            $insData['formc_number']        = $formCId;
            $insData['name']                = $name;
            $insData['f_name']              = $fName;
            $insData['address_present']     = $addressPresent;
            $insData['address_parmanent']   = $addressPermanent;
            $insData['cnic']                = $cnic;
            $insData['date_issued']         = $dateIssued;
            $insData['is_issued']           = $isIssued;
            $insData['system_id']           = $systemId;
            $insData['note']                = $note;
            $insData['branch_id']           = $branchId;
           
            $issueFormD = Domicile::issueFormC($insData);

            return response(['status' => 'success', 'data' => $issueFormD]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch pending count
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchPendingCasesCount(Request $request) {
        try {
            
            $pendingDomiciles        = Domicile::penddingDomicilesCount();

            return response(['status' => 'success', 'data' => $pendingDomiciles]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch issue cases count
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchIssuedCasesTodayCount(Request $request) {
        try {
            
            $issueDomiciles        = Domicile::issuedDomicilesCountToday();

            return response(['status' => 'success', 'data' => $issueDomiciles]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch issue cases by filter
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchIssuedCasesFilter(Request $request) {
        try {
            
            $issueDomiciles        = Domicile::issuedDomicilesFilter($request->filter);

            return response(['status' => 'success', 'data' => $issueDomiciles]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch all cases
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchAllCases(Request $request) {
        try {
            
            $request->validate([
                'date' => 'required'
            ]);

            $allDomiciles        = Domicile::fetchAllCases($request->date);

            return response(['status' => 'success', 'data' => $allDomiciles]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * fetch cancel count
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function fetchCancelledCasesCount(Request $request) {
        try {
            
            $cancelledDomiciles        = Domicile::cancelledAllDomicilesCount();

            return response(['status' => 'success', 'data' => $cancelledDomiciles]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * update the applicant profile
     *  @param  \Illuminate\Http\Request  $request
     *  @return \Illuminate\Http\Response
     */
    public function updateApplicantProfile(Request $request) {
        try {
            $request->validate([
                'name'                  => 'required',
                'f_name'                => 'required',
                'address_present'       => 'required',
                'address_parmanent'     => 'required',
                'address_outside_pak'   => 'required',
                'date_arrival_domicile' => 'required',
                'marital_status'        => 'required',
                'children_name_age'     => 'required',
                'occupassion'           => 'required',
                'identification'        => 'required',
                'guardian_cnic_no'      => 'required',
                'dob'                   => 'required',
                'qualification'         => 'required',
                'record_id'             => 'required',
                'cnic'                  => 'required',
                'cnic_issued_date'      => 'required',
                'note'                  => 'required',
                'spouce'                => 'required',
                'guardian_cnic_issued_date' => 'required',
                'formb_issued_date'     =>'required',
                'property_docs'         => 'required',
                'contact_no'            => 'required',
                'gender'                => 'required',
                'union_council'         => 'required',
                'tehsil_province'       => 'required',
                'utility_bill'          => 'required',
                'primary_from'          => 'required',
                'primary_year'          => 'required',
                'middle_from'           => 'required',
                'middle_year'           => 'required',
                'matric_from'           => 'required',
                'matric_year'           => 'required',
                'inter_from'            => 'required',
                'inter_year'            => 'required',
                'ba_from'               => 'required',
                'ba_year'               => 'required',
                'other_from'            => 'required',
                'other_year'            => 'required',
                'challan_no'            => 'required',
                'challan_date'          => 'required',
                'affidavit'             => 'required',
                'nikkah_nama'           => 'required',
                'service_certificate'   => 'required',
                'children_name_age'     => 'required',

            ]);

            // $inputData = [
            //     'name'                  => $request->name,
            //     'f_name'                => $request->f_name,
            //     'address_present'       => $request->address_present,
            //     'address_outside_pak'   => $request->address_outside_pak,
            //     'marital_status'        => $request->marital_status,
            //     'children_name_age'     => $request->children_name_age,
            //     'occupassion'           => $request->occupassion,
            //     'identification'        => $request->identification,
            //     'guardian_cnic_no'      => $request->guardian_cnic_no,
            //     'dob'                   => $request->dob,
            //     'qualification'         => $request->qualification,
            //     'cnic'                  => $request->cnic,
            //     'note'                  => $request->note
            // ];

            $inputData = [
                    'name'                  => $request->name,
                    'f_name'                => $request->f_name,
                    'address_present'       => $request->address_present,
                    'address_parmanent'     => $request->address_parmanent,
                    'address_outside_pak'   => $request->address_outside_pak,
                    'date_arrival_domicile' => $request->date_arrival_domicile,
                    'marital_status'        => $request->marital_status,
                    'children_name_age'     => $request->children_name_age,
                    'occupassion'           => $request->occupassion,
                    'identification'        => $request->identification,
                    'guardian_cnic_no'      => $request->guardian_cnic_no,
                    'dob'                   => $request->dob,
                    'qualification'         => $request->qualification,
                    'cnic'                  => $request->cnic,
                    'cnic_issued_date'      => $request->cnic_issued_date,
                    'note'                  => $request->note,
                    'spouce'                => $request->spouce,
                    'guardian_cnic_issued_date' => $request->guardian_cnic_issued_date,
                    'formb_issued_date'     =>  $request->formb_issued_date,
                    'property_docs'         => $request->property_docs,
                    'contact_no'            => $request->contact_no,
                    'gender'                => $request->gender,
                    'union_council'         => $request->union_council,
                    'tehsil_province'       => $request->tehsil_province,
                    'utility_bill'          => $request->utility_bill,
                    'primary_from'          => $request->primary_from,
                    'primary_year'          => $request->primary_year,
                    'middle_from'           => $request->middle_from,
                    'middle_year'           => $request->middle_year,
                    'matric_from'           => $request->matric_from,
                    'matric_year'           => $request->matric_year,
                    'inter_from'            => $request->inter_from,
                    'inter_year'            => $request->inter_year,
                    'ba_from'               => $request->ba_from,
                    'ba_year'               => $request->ba_year,
                    'other_from'            => $request->other_from,
                    'other_year'            => $request->other_year,
                    'challan_no'            => $request->challan_no,
                    'challan_date'          => $request->challan_date,
                    'affidavit'             => $request->affidavit,
                    'nikkah_nama'           => $request->nikkah_nama,
                    'service_certificate'   => $request->service_certificate,
                    'children_name_age'     => $request->children_name_age
            ];
            if($request->has('image_path') && $request->image_path !="")
                $inputData['image_path'] = $request->image_path; 

            $updateStatus = Domicile::updateApplicantProfile($inputData,$request->record_id);
            
            return response(['status' => 'success', 'data' => $updateStatus]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * filter the issue domicile.
     *
     * @param  \Illuminate\Http\Request
     * @return \Illuminate\Http\Response
     */
    public function filterIssueDomicile(Request $request)
    {
        try {
            $issueCases = Domicile::filterIssueDomicile($request->month,$request->year);
            return response(['status' => 'success', 'data' => $issueCases]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * filter the issue form c.
     *
     * @param  \Illuminate\Http\Request
     * @return \Illuminate\Http\Response
     */
    public function filterIssueFormC(Request $request)
    {
        try {
            $issueCases = Domicile::filterIssueFormC($request->month,$request->year);
            return response(['status' => 'success', 'data' => $issueCases]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * filter the issue form d.
     *
     * @param  \Illuminate\Http\Request
     * @return \Illuminate\Http\Response
     */
    public function filterIssueFormD(Request $request)
    {
        try {
            $issueCases = Domicile::filterIssueFormD($request->month,$request->year);
            return response(['status' => 'success', 'data' => $issueCases]);
        }
        catch(\Exception $e) {
            return response(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }
    /**
     * generate new password for admin users
     *
     * @param  \Illuminate\Http\Request
     * @return \Illuminate\Http\Response
     */
    function changeUserNamePassword(Request $request) {
        
        $adminId = $request->admin_id;
        $adminName = $request->admin_name;
        $password = $request->password;
        echo $encodePass = Crypt::encrypt($password);

    }
}
?>