<?php
use App\Http\Controllers\domicileApi as DomicileApiController;
use App\Http\Controllers\VerifyDomicile as VerifyDomicileController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::get('/test', function (Request $request) {
    
    $ip = $request->ip();
    return response(['status' => 'success', 'message' => 'api is working', 'headers' => $request->header()], 200);
});

Route::post("create/user",[DomicileApiController::class, 'createUser']);
Route::post("login/user",[DomicileApiController::class, 'loginMe']);

// bypass auth:
Route::group(['prefix' => 'v2/','middleware' => 'authuser'],function () {
    Route::post('add/domicile/data', [DomicileApiController::class, 'addDomicileData']);
    Route::post('fetch/domiciles/details', [DomicileApiController::class, 'showDomicilesDetails']);
    Route::post('fetch/applicant/details', [DomicileApiController::class, 'fetchApplicantDetails']);
    Route::post('update/domicile/status', [DomicileApiController::class, 'updateDomicileStatus']);

    Route::get('update/domicile/teststatus', [DomicileApiController::class, 'updateDomicileStatusTest']);

    Route::post('update/domicile', [DomicileApiController::class, 'updateDomicile']);
    Route::post('update/col', [DomicileApiController::class, 'updateColVal']);
    Route::post('update/applicant/profile', [DomicileApiController::class, 'updateApplicantProfile']);
    Route::post('update/verified/doc', [DomicileApiController::class, 'updateVerifiedDoc']);
    Route::post('search/applicant', [DomicileApiController::class, 'searchApplicant']);
    Route::post('fetch/cases/except/issued', [DomicileApiController::class, 'fetchCasesExceptIssued']);
    Route::post('fetch/cases/issued/except', [DomicileApiController::class, 'fetchExceptIssuedCases']);
    Route::post('generate/domicileid', [DomicileApiController::class, 'generateDomicileId']);
    Route::post('upload/pdf', [DomicileApiController::class, 'uploadPdf']);
    Route::post('upload/file', [DomicileApiController::class, 'uploadFile']);
    Route::post('upload/verified/pdf', [DomicileApiController::class, 'uploadVerifiedPdf']);
    Route::post('upload/image', [DomicileApiController::class, 'uploadImage']);
    Route::post('pending/cases', [DomicileApiController::class, 'fetchPendingCasesCount']);
    Route::post('issued/cases', [DomicileApiController::class, 'fetchIssuedCasesTodayCount']);
    Route::post('issued/cases/filter', [DomicileApiController::class, 'fetchIssuedCasesFilter']);
    Route::post('fetch/issued/cases/between/dates', [DomicileApiController::class, 'fetchIssuedCasesBetweenDates']);
    Route::post('cancelled/cases', [DomicileApiController::class, 'fetchCancelledCasesCount']);
    Route::post('issue/remaining/docs', [DomicileApiController::class, 'issueRemainingDocs']);
    Route::post('fetch/all/cases', [DomicileApiController::class, 'fetchAllCases']);
    Route::post('upload/remaining/docs', [DomicileApiController::class, 'uploadRemainingDocs']);

    Route::post('fetch/issued/domiciles', [DomicileApiController::class, 'filterIssueDomicile']);
    Route::post('fetch/issued/formc', [DomicileApiController::class, 'filterIssueFormC']);
    Route::post('fetch/issued/formd', [DomicileApiController::class, 'filterIssueFormD']);
    Route::get('verify/domicile', [VerifyDomicileController::class, 'index']);
    
     Route::get('view/file', [DomicileApiController::class, 'viewFile']);
     
     Route::post('fetch/except/issued/domiciles', [DomicileApiController::class, 'filterExceptIssueDomicile']);
 
});

Route::prefix('v1')->group(function () {
    Route::post('login', [DomicileApiController::class, 'login']);
    Route::post('add/domicile/data', [DomicileApiController::class, 'addDomicileData']);
    Route::post('fetch/domiciles/details', [DomicileApiController::class, 'showDomicilesDetails']);
    Route::post('fetch/applicant/details', [DomicileApiController::class, 'fetchApplicantDetails']);
    Route::post('update/domicile/status', [DomicileApiController::class, 'updateDomicileStatus']);

    Route::get('update/domicile/teststatus', [DomicileApiController::class, 'updateDomicileStatusTest']);

    Route::post('update/domicile', [DomicileApiController::class, 'updateDomicile']);
    Route::post('update/col', [DomicileApiController::class, 'updateColVal']);
    Route::post('update/applicant/profile', [DomicileApiController::class, 'updateApplicantProfile']);
    Route::post('update/verified/doc', [DomicileApiController::class, 'updateVerifiedDoc']);
    Route::post('search/applicant', [DomicileApiController::class, 'searchApplicant']);
    Route::post('fetch/cases/except/issued', [DomicileApiController::class, 'fetchCasesExceptIssued']);
    Route::post('fetch/cases/issued/except', [DomicileApiController::class, 'fetchExceptIssuedCases']);
    Route::post('generate/domicileid', [DomicileApiController::class, 'generateDomicileId']);
    Route::post('upload/pdf', [DomicileApiController::class, 'uploadPdf']);
    Route::post('upload/file', [DomicileApiController::class, 'uploadFile']);
    Route::post('upload/verified/pdf', [DomicileApiController::class, 'uploadVerifiedPdf']);
    Route::post('upload/image', [DomicileApiController::class, 'uploadImage']);
    Route::post('pending/cases', [DomicileApiController::class, 'fetchPendingCasesCount']);
    Route::post('issued/cases', [DomicileApiController::class, 'fetchIssuedCasesTodayCount']);
    Route::post('issued/cases/filter', [DomicileApiController::class, 'fetchIssuedCasesFilter']);
    Route::post('fetch/issued/cases/between/dates', [DomicileApiController::class, 'fetchIssuedCasesBetweenDates']);
    Route::post('cancelled/cases', [DomicileApiController::class, 'fetchCancelledCasesCount']);
    Route::post('issue/remaining/docs', [DomicileApiController::class, 'issueRemainingDocs']);
    Route::post('fetch/all/cases', [DomicileApiController::class, 'fetchAllCases']);
    Route::post('upload/remaining/docs', [DomicileApiController::class, 'uploadRemainingDocs']);

    Route::post('fetch/issued/domiciles', [DomicileApiController::class, 'filterIssueDomicile']);
    Route::post('fetch/issued/formc', [DomicileApiController::class, 'filterIssueFormC']);
    Route::post('fetch/issued/formd', [DomicileApiController::class, 'filterIssueFormD']);
    Route::get('verify/domicile', [VerifyDomicileController::class, 'index']);
});
